<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:adf="urn:avicomsys-ru:adf-preview">
  <xsl:variable name="lang" select="adf:GetLanguage()" />
	<xsl:template match="/">
		<HTML>
			<HEAD>
				<TITLE>
					<xsl:value-of select="pjm5CalculationGet/Calculation/FileAs" />
				</TITLE>
				<xsl:value-of select="adf:GetCss()" disable-output-escaping="yes" />
			</HEAD>
			<BODY >
				<xsl:value-of select="adf:GetHeader(pjm5CalculationGet/Calculation)"  disable-output-escaping="yes"/>
				<xsl:apply-templates select="//Calculation"/>
				<br />
				<xsl:choose>
					<xsl:when test="//CalculationLine/ID">
						<table border="1" cellspacing="0" cellpadding="4">
							<tr>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Дата
                    </xsl:when>
                    <xsl:otherwise>
                      Date
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Описание
                    </xsl:when>
                    <xsl:otherwise>
                      Description
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Кол-во
                    </xsl:when>
                    <xsl:otherwise>
                      Amount
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Цена
                    </xsl:when>
                    <xsl:otherwise>
                      Price
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Сумма
                    </xsl:when>
                    <xsl:otherwise>
                      Total
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Валюта
                    </xsl:when>
                    <xsl:otherwise>
                      Currency
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
							</tr>
							<xsl:for-each select="//CalculationLine">
								<xsl:apply-templates select="."/>
							</xsl:for-each>
						</table>

					</xsl:when>
					<xsl:otherwise>	</xsl:otherwise>
				</xsl:choose>

				<xsl:value-of select="adf:GetFooter(pjm5CalculationGet/Calculation)"  disable-output-escaping="yes"/>

			</BODY>
		</HTML>
	</xsl:template>

	<xsl:template match="CalculationLine">
		<tr>
			<td>
				<xsl:value-of select="adf:FormatXmlDate(Date,'d')"/>
			</td>
			<td>
				<xsl:value-of select="EmployeeName"/>
			</td>
			<td align="right">
				<xsl:variable name="x" select="Amount"/>
				<xsl:value-of select="format-number($x,'#,##0.00')"/>
			</td>
			<td align="right">
				<xsl:variable name="v" select="PriceWithVAT"/>
				<xsl:value-of select="format-number($v,'#,##0.00')"/>
			</td>
			<td align="right">
				<xsl:variable name="w" select="SumWithVAT"/>
				<xsl:value-of select="format-number($w,'#,##0.00')"/>
			</td>
			<td>
				<xsl:value-of select="//Calculation/CurrencyCode"/>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="Calculation">
		<table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">
			<tr>
				<td>
					<br />
					<xsl:choose>
						<xsl:when test="Date">
							<strong> 
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  Дата:
                </xsl:when>
                <xsl:otherwise>
                  Date:
                </xsl:otherwise>
              </xsl:choose>
            </strong>
							<xsl:value-of select="adf:FormatXmlDate(Date,'d')"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<br/>
					<xsl:choose>
						<xsl:when test="DocumentClass">
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Тип:
                  </xsl:when>
                  <xsl:otherwise>
                    Type:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetDocumentTitle(DocumentClass)"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>

			<tr>
				<td>
					<br/>
					<xsl:choose>
						<xsl:when test="ContractNumber">
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Договор:
                  </xsl:when>
                  <xsl:otherwise>
                    Project Code:
                  </xsl:otherwise>
                </xsl:choose> </strong>
							<xsl:value-of select="ContractNumber"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<br/>
					<xsl:choose>
						<xsl:when test="CustomerCompanyID">
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Покупатель:
                  </xsl:when>
                  <xsl:otherwise>
                    Customer:
                  </xsl:otherwise>
                </xsl:choose> </strong>
							<xsl:value-of select="adf:GetListMember(CustomerCompanyID, 'Company', 'Name')"/>
						</xsl:when>
						<xsl:otherwise> </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<br/>
					<xsl:choose>
						<xsl:when test="SupplierCompanyID">
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Поставщик:
                  </xsl:when>
                  <xsl:otherwise>
                    Supplier:
                  </xsl:otherwise>
                </xsl:choose> </strong>

							<xsl:value-of select="adf:GetListMember(SupplierCompanyID, 'Company', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>

					<xsl:choose>
						<xsl:when test="PeriodStart">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Период:
                  </xsl:when>
                  <xsl:otherwise>
                    Period:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:FormatXmlDate(PeriodStart,'d')"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
					<strong> - </strong>
					<xsl:choose>
						<xsl:when test="PeriodEnd">
							<xsl:value-of select="adf:FormatXmlDate(PeriodEnd,'d')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>

				</td>
			</tr>
			<tr>
				<td>

					<xsl:choose>
						<xsl:when test="VATRate">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Ставка НДС,%:
                  </xsl:when>
                  <xsl:otherwise>
                    VAT rate,%:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="VATRate * 100"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
				
					<xsl:choose>
						<xsl:when test="VAT">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    НДС:
                  </xsl:when>
                  <xsl:otherwise>
                    VAT:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:variable name="x" select="VAT"/>
							<xsl:value-of select="format-number($x,'0.##')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
				
					<xsl:choose>
						<xsl:when test="TotalWithVAT">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Сумма:
                  </xsl:when>
                  <xsl:otherwise>
                    Total:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:variable name="y" select="TotalWithVAT"/>
							<xsl:value-of select="format-number($y,'0.##')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					
					<xsl:choose>
						<xsl:when test="Total">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Сумма без НДС:
                  </xsl:when>
                  <xsl:otherwise>
                    Total Without VAT:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:variable name="z" select="Total"/>
							<xsl:value-of select="format-number($z,'0.##')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>

					<xsl:choose>
						<xsl:when test="TotalPC">
							<br/>
							<strong> 
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  Сумма без НДС в валюте проекта:
                </xsl:when>
                <xsl:otherwise>
                  Total in project currency Without VAT:
                </xsl:otherwise>
              </xsl:choose>
            </strong>
							
							<xsl:variable name="a1" select="TotalPC"/>
							<xsl:value-of select="format-number($a1,'0.##')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					
					<xsl:choose>
						<xsl:when test="TotalWithVATPC">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Сумма c НДС в валюте проекта:
                  </xsl:when>
                  <xsl:otherwise>
                    Total In Project Currency With VAT:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							
							<xsl:variable name="a2" select="TotalWithVATPC"/>
							<xsl:value-of select="format-number($a2,'0.##')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="CurrencyCode">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Валюта:
                  </xsl:when>
                  <xsl:otherwise>
                    Currency:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							
							<xsl:value-of select="CurrencyCode"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
		</table>
	</xsl:template>
</xsl:stylesheet>