<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:adf="urn:avicomsys-ru:adf-preview">

  <xsl:variable name="lang" select="adf:GetLanguage()" />
	<xsl:template match="/">
	
		<HTML>
			<HEAD>
				<TITLE>
					<xsl:value-of select="adfPaymentGet/Payment/FileAs" />
				</TITLE>
				<xsl:value-of select="adf:GetCss()" disable-output-escaping="yes" />
			</HEAD>
			<BODY >
				<xsl:value-of select="adf:GetHeader(adfPaymentGet/Payment)"  disable-output-escaping="yes"/>
				<xsl:apply-templates select="//Payment"/>
				<xsl:choose>
					<xsl:when test="//PaymentLine/ID">
						<table border="1" cellspacing="0" cellpadding="4">
							<tr>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Номер
                    </xsl:when>
                    <xsl:otherwise>
                      Number
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Дата
                    </xsl:when>
                    <xsl:otherwise>
                      Date
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Сумма счета
                    </xsl:when>
                    <xsl:otherwise>
                      Invoice Value
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Сумма
                    </xsl:when>
                    <xsl:otherwise>
                      Payment Value
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      НДС
                    </xsl:when>
                    <xsl:otherwise>
                      VAT
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Валюта
                    </xsl:when>
                    <xsl:otherwise>
                      Currency
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
							</tr>
							<xsl:for-each select="//PaymentLine">
								<xsl:apply-templates select=".">	
								</xsl:apply-templates>
							</xsl:for-each>
						</table>

					</xsl:when>
					<xsl:otherwise>	</xsl:otherwise>
				</xsl:choose>

				<xsl:value-of select="adf:GetFooter(adfPaymentGet/Payment)"  disable-output-escaping="yes"/>

			</BODY>
		</HTML>
	</xsl:template>

	<xsl:template match="PaymentLine">
		<tr>
			<td>
				<xsl:value-of select="Number"/>
			</td>
			<td>
				<xsl:value-of select="adf:FormatXmlDate(Date,'d')"/>
			</td>
			<td>
				<xsl:variable name="bp" select="Sum"/>
				<xsl:value-of select="format-number($bp,'0.##')"/>
			</td>
			<td>
				<xsl:variable name="bp1" select="PaymentValue"/>
				<xsl:value-of select="format-number($bp1,'0.##')"/>
			</td>
			<td>
				<xsl:variable name="bp2" select="PaymentVAT"/>
				<xsl:value-of select="format-number($bp2,'0.##')"/>

			</td>
			<td>
				<xsl:apply-templates select="//Payment/CurrencyCode"/>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="CurrencyCode">
		<xsl:value-of select="."/>
	</xsl:template>
	<xsl:template match="Payment">
		<table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">
			<xsl:variable name="cur" select="CurrencyCode"></xsl:variable>
			<xsl:variable name="bcur">RUB</xsl:variable>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="Date">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Дата:
                  </xsl:when>
                  <xsl:otherwise>
                    Date:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:FormatXmlDate(Date,'d')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
			
					<xsl:choose>
						<xsl:when test="PayeeCompanyID">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Плательщик:
                  </xsl:when>
                  <xsl:otherwise>
                    Payer:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(PayerCompanyID, 'Company', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="PayeeCompanyID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Получатель:
                  </xsl:when>
                  <xsl:otherwise>
                    Recipient:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(PayeeCompanyID, 'Company', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="PaymentTypeID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Тип платежа:
                  </xsl:when>
                  <xsl:otherwise>
                    Type:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(PaymentTypeID, 'PaymentType', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="PayeeBankAccountID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Расчетный счет:
                  </xsl:when>
                  <xsl:otherwise>
                    Bank Account:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(PayeeBankAccountID, 'BankAccount', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="Payer">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Принято от:
                  </xsl:when>
                  <xsl:otherwise>
                    Payer:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="Payer"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="Reason">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Основание:
                  </xsl:when>
                  <xsl:otherwise>
                    Reason:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="Reason"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>

			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="Value">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Сумма:
                  </xsl:when>
                  <xsl:otherwise>
                    Total:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:variable name="x" select="Value"/>
							<xsl:value-of select="format-number($x,'0.##')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="VAT">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    НДС:
                  </xsl:when>
                  <xsl:otherwise>
                    VAT:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:variable name="x" select="VAT"/>
							<xsl:value-of select="format-number($x,'0.##')"/> 
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="CurrencyCode">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Валюта:
                  </xsl:when>
                  <xsl:otherwise>
                    Currency:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="CurrencyCode"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
					<br />
				</td>
			</tr>
			<tr>
				<td>
					<xsl:if test="$cur">
						<xsl:if test="$bcur!=$cur">
							<xsl:choose>
								<xsl:when test="BaseCurrencyRate">
									<br />
									<strong>
                    <xsl:choose>
                      <xsl:when test="$lang = 'ru'">
                        Курс валюты:
                      </xsl:when>
                      <xsl:otherwise>
                        Currency Rate:
                      </xsl:otherwise>
                    </xsl:choose>
                  </strong>
									1 <xsl:value-of select="CurrencyCode"/> = <xsl:variable name="cr" select="BaseCurrencyRate"/> <xsl:value-of select="format-number($cr,'0.##')"/><xsl:text> </xsl:text> RUB
								</xsl:when>
								<xsl:otherwise>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Курс <xsl:value-of select="CurrencyCode"/> к RUB не указан
                    </xsl:when>
                    <xsl:otherwise>
                      Rate <xsl:value-of select="CurrencyCode"/> to RUB is not defined
                    </xsl:otherwise>
                  </xsl:choose>
									
								</xsl:otherwise>
							</xsl:choose>
						</xsl:if>
					</xsl:if>
				</td>
			</tr>
		</table>
		<br/>
	</xsl:template>
</xsl:stylesheet>